@@ -1,5 +1,3 @@
-use std::rc::Rc;
-
 use clvm_rs::allocator::{Allocator, NodePtr};
 use clvm_rs::chia_dialect::{ChiaDialect, NO_NEG_DIV, NO_UNKNOWN_OPS};
 use clvm_rs::cost::Cost;
@@ -31,6 +29,12 @@ impl DefaultProgramRunner {
     }
 }
 
+impl Default for DefaultProgramRunner {
+    fn default() -> Self {
+        DefaultProgramRunner::new()
+    }
+}
+
 impl TRunProgram for DefaultProgramRunner {
     fn run_program(
         &self,
@@ -39,10 +43,7 @@ impl TRunProgram for DefaultProgramRunner {
         args: NodePtr,
         option: Option<RunProgramOption>,
     ) -> Response {
-        let max_cost = option
-            .as_ref()
-            .and_then(|o| o.max_cost)
-            .unwrap_or_else(|| 0);
+        let max_cost = option.as_ref().and_then(|o| o.max_cost).unwrap_or(0);
 
         run_program(
             allocator,
