@@ -183,6 +183,12 @@ fn make_cons(a: Rc<SExp>, b: Rc<SExp>) -> SExp {
     SExp::Cons(a.loc().ext(&b.loc()), a.clone(), b.clone())
 }
 
+#[derive(Debug, PartialEq, Eq)]
+enum TermListCommentState {
+    InComment,
+    Empty,
+}
+
 #[derive(Debug)]
 enum SExpParseState {
     Empty,
@@ -192,7 +198,13 @@ enum SExpParseState {
     QuotedEscaped(Srcloc, u8, Vec<u8>),
     OpenList(Srcloc),
     ParsingList(Srcloc, Rc<SExpParseState>, Vec<Rc<SExp>>),
-    TermList(Srcloc, Rc<SExpParseState>, Vec<Rc<SExp>>),
+    TermList(
+        Srcloc,
+        TermListCommentState,
+        Option<Rc<SExp>>,
+        Rc<SExpParseState>,
+        Vec<Rc<SExp>>,
+    ),
 }
 
 #[derive(Debug)]
@@ -310,7 +322,7 @@ fn escape_quote(q: u8, s: &[u8]) -> String {
     let _: Vec<()> = s
         .iter()
         .map(|ch| {
-            if *ch == q as u8 {
+            if *ch == q {
                 res.push('\\');
             }
             res.push(*ch as char);
@@ -583,6 +595,8 @@ fn parse_sexp_step(loc: Srcloc, p: &SExpParseState, this_char: u8) -> SExpParseR
             match (this_char as char, pp.borrow()) {
                 ('.', SExpParseState::Empty) => resume(SExpParseState::TermList(
                     pl.ext(&loc),
+                    TermListCommentState::Empty,
+                    None,
                     Rc::new(SExpParseState::Empty),
                     list_content.to_vec(),
                 )),
@@ -616,61 +630,120 @@ fn parse_sexp_step(loc: Srcloc, p: &SExpParseState, this_char: u8) -> SExpParseR
                 },
             }
         }
-        SExpParseState::TermList(pl, pp, list_content) => match (this_char as char, pp.borrow()) {
-            ('.', SExpParseState::Empty) => {
-                error(loc, "Multiple dots in list notation are illegal")
-            }
-            (')', SExpParseState::Empty) => {
-                if list_content.len() == 1 {
-                    emit(list_content[0].clone(), SExpParseState::Empty)
-                } else {
-                    emit(
-                        Rc::new(enlist(pl.ext(&loc), list_content.to_vec())),
-                        SExpParseState::Empty,
-                    )
-                }
-            }
-            (')', SExpParseState::Bareword(l, t)) => {
-                let parsed_atom = make_atom(l.clone(), t.to_vec());
+        SExpParseState::TermList(pl, TermListCommentState::InComment, parsed, pp, list_content) => {
+            let end_comment = if this_char as char == '\n' || this_char as char == '\r' {
+                TermListCommentState::Empty
+            } else {
+                TermListCommentState::InComment
+            };
+            resume(SExpParseState::TermList(
+                pl.clone(),
+                end_comment,
+                parsed.clone(),
+                pp.clone(),
+                list_content.clone(),
+            ))
+        }
+        SExpParseState::TermList(
+            pl,
+            TermListCommentState::Empty,
+            Some(parsed),
+            pp,
+            list_content,
+        ) => {
+            if this_char.is_ascii_whitespace() {
+                resume(SExpParseState::TermList(
+                    pl.ext(&loc),
+                    TermListCommentState::Empty,
+                    Some(parsed.clone()),
+                    pp.clone(),
+                    list_content.to_vec(),
+                ))
+            } else if this_char == b')' {
                 let mut list_copy = list_content.to_vec();
                 match list_copy.pop() {
                     Some(v) => {
-                        let new_tail = make_cons(v, Rc::new(parsed_atom));
+                        let new_tail = make_cons(v, parsed.clone());
                         if list_copy.is_empty() {
                             emit(Rc::new(new_tail), SExpParseState::Empty)
                         } else {
-                            list_copy.push(Rc::new(new_tail));
-                            let new_list = enlist(pl.ext(&loc), list_copy);
-                            emit(Rc::new(new_list), SExpParseState::Empty)
+                            let mut result_list = new_tail;
+                            for item in list_copy.iter().rev() {
+                                result_list = make_cons(item.clone(), Rc::new(result_list));
+                            }
+                            emit(Rc::new(result_list), SExpParseState::Empty)
                         }
                     }
                     None => error(loc, "Dot as first element of list?"),
                 }
+            } else if this_char == b';' {
+                resume(SExpParseState::TermList(
+                    pl.clone(),
+                    TermListCommentState::InComment,
+                    Some(parsed.clone()),
+                    pp.clone(),
+                    list_content.clone(),
+                ))
+            } else {
+                error(
+                    pl.clone(),
+                    &format!("unexpected character {}", this_char as char),
+                )
             }
-            (_, _) => match parse_sexp_step(loc.clone(), pp.borrow(), this_char) {
-                SExpParseResult::Emit(o, p) => {
+        }
+        SExpParseState::TermList(pl, TermListCommentState::Empty, None, pp, list_content) => {
+            match (this_char as char, pp.borrow()) {
+                ('.', SExpParseState::Empty) => {
+                    error(loc, "Multiple dots in list notation are illegal")
+                }
+                (')', SExpParseState::Empty) => {
+                    if list_content.len() == 1 {
+                        emit(list_content[0].clone(), SExpParseState::Empty)
+                    } else {
+                        emit(
+                            Rc::new(enlist(pl.ext(&loc), list_content.to_vec())),
+                            SExpParseState::Empty,
+                        )
+                    }
+                }
+                (')', SExpParseState::Bareword(l, t)) => {
+                    let parsed_atom = make_atom(l.clone(), t.to_vec());
                     let mut list_copy = list_content.to_vec();
                     match list_copy.pop() {
                         Some(v) => {
-                            let new_tail = make_cons(v, o);
-                            list_copy.push(Rc::new(new_tail));
-                            resume(SExpParseState::TermList(
-                                pl.ext(&loc),
-                                Rc::new(p),
-                                list_copy,
-                            ))
+                            let new_tail = make_cons(v, Rc::new(parsed_atom));
+                            if list_copy.is_empty() {
+                                emit(Rc::new(new_tail), SExpParseState::Empty)
+                            } else {
+                                let mut result_list = new_tail;
+                                for item in list_copy.iter().rev() {
+                                    result_list = make_cons(item.clone(), Rc::new(result_list));
+                                }
+                                emit(Rc::new(result_list), SExpParseState::Empty)
+                            }
                         }
                         None => error(loc, "Dot as first element of list?"),
                     }
                 }
-                SExpParseResult::Resume(p) => resume(SExpParseState::TermList(
-                    pl.ext(&loc),
-                    Rc::new(p),
-                    list_content.to_vec(),
-                )),
-                SExpParseResult::Error(l, e) => SExpParseResult::Error(l, e),
-            },
-        },
+                (_, _) => match parse_sexp_step(loc.clone(), pp.borrow(), this_char) {
+                    SExpParseResult::Emit(o, _p) => resume(SExpParseState::TermList(
+                        loc,
+                        TermListCommentState::Empty,
+                        Some(o),
+                        pp.clone(),
+                        list_content.clone(),
+                    )),
+                    SExpParseResult::Resume(p) => resume(SExpParseState::TermList(
+                        pl.ext(&loc),
+                        TermListCommentState::Empty,
+                        None,
+                        Rc::new(p),
+                        list_content.to_vec(),
+                    )),
+                    SExpParseResult::Error(l, e) => SExpParseResult::Error(l, e),
+                },
+            }
+        }
     }
 }
 
@@ -713,7 +786,7 @@ where
         }
         SExpParseState::OpenList(l) => Err((l, "Unterminated list (empty)".to_string())),
         SExpParseState::ParsingList(l, _, _) => Err((l, "Unterminated mid list".to_string())),
-        SExpParseState::TermList(l, _, _) => Err((l, "Unterminated tail list".to_string())),
+        SExpParseState::TermList(l, _, _, _, _) => Err((l, "Unterminated tail list".to_string())),
     }
 }
 
