@@ -18,7 +18,7 @@ extern crate tempfile;
 
 extern crate clvmr as clvm_rs;
 
-mod util;
+pub mod util;
 
 pub mod classic;
 pub mod compiler;
@@ -29,6 +29,3 @@ mod py;
 
 #[cfg(test)]
 mod tests;
-
-#[cfg(target_family = "wasm")]
-pub mod wasm;
