@@ -5,7 +5,6 @@ import traceback
 recompile_list = [
     'block_program_zero.clvm',
     'calculate_synthetic_public_key.clvm',
-    'cat.clvm',
     'chialisp_deserialisation.clvm',
     'decompress_coin_spend_entry.clvm',
     'decompress_coin_spend_entry_with_prefix.clvm',
@@ -13,7 +12,6 @@ recompile_list = [
     'delegated_tail.clvm',
     'did_innerpuz.clvm',
     'everything_with_signature.clvm',
-    'generator_for_single_coin.clvm',
     'genesis_by_coin_id.clvm',
     'genesis_by_puzzle_hash.clvm',
     'lock.inner.puzzle.clvm',
@@ -32,8 +30,6 @@ recompile_list = [
     'p2_singleton_or_delayed_puzhash.clvm',
     'pool_member_innerpuz.clvm',
     'pool_waitingroom_innerpuz.clvm',
-    'rl_aggregation.clvm',
-    'rl.clvm',
     'rom_bootstrap_generator.clvm',
     'settlement_payments.clvm',
     'sha256tree_module.clvm',
